/* 
 * GSEGYLIB - Library for accessing files in SEG-Y format
 *
 * Copyright (C) 2005-2006 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEGY_FILE_H__
#define __G_SEGY_FILE_H__

#include <gsegyfile/gsegyerror.h>
#include <gsegyfile/gsegyformatwizard.h>
#include <gsegyfile/gsegyseismicaccessor.h>

G_BEGIN_DECLS

#define G_SEGY_TYPE_FILE            (g_segy_file_get_type ())
#define G_SEGY_FILE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_SEGY_TYPE_FILE, GSEGYFile))
#define G_SEGY_FILE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), G_SEGY_TYPE_FILE, GSEGYFileClass))
#define G_SEGY_IS_FILE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_SEGY_TYPE_FILE))
#define G_SEGY_IS_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), G_SEGY_TYPE_FILE))
#define G_SEGY_GET_FILE_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), G_SEGY_TYPE_FILE, GSEGYFileClass))

typedef struct _GSEGYFile GSEGYFile;
typedef struct _GSEGYFileClass GSEGYFileClass;

struct _GSEGYFile {
    GObject parent;
};

struct _GSEGYFileClass {
    GObjectClass parent_class;

    guint scan_fraction_id;

    gboolean (*scan_fraction) (GSEGYFile *self, gfloat fraction, GSEGYFileError *file_error);
};

GType g_segy_file_get_type (void);

GSEGYFile* g_segy_file_new (const gchar *filename);
GSEGYFileError* g_segy_file_get_error (GSEGYFile *self);
GSEGYFileAccessor* g_segy_file_get_file_accessor (GSEGYFile *self);
GSEGYSeismicAccessor* g_segy_file_get_seismic_accessor (GSEGYFile *self);

gboolean g_segy_file_set_format (GSEGYFile *self, GSEGYFormatWizard *format_wizard, GSEGYFileError *file_error);

G_END_DECLS
#endif /* __G_SEGY_FILE_H__ */
