/* 
 * GSEGYLIB - Library for accessing files in SEG-Y format
 *
 * Copyright (C) 2005-2007 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEGY_FORMAT_WIZARD_H__
#define __G_SEGY_FORMAT_WIZARD_H__

#include <gsegyfile/gsegyendianess.h>

G_BEGIN_DECLS

#define G_SEGY_TYPE_FORMAT_WIZARD            (g_segy_format_wizard_get_type ())
#define G_SEGY_FORMAT_WIZARD(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), G_SEGY_TYPE_FORMAT_WIZARD, GSEGYFormatWizard))
#define G_SEGY_FORMAT_WIZARD_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), G_SEGY_TYPE_FORMAT_WIZARD, GSEGYFormatWizardClass))
#define G_SEGY_IS_FORMAT_WIZARD(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_SEGY_TYPE_FORMAT_WIZARD))
#define G_SEGY_IS_FORMAT_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), G_SEGY_TYPE_FORMAT_WIZARD))
#define G_SEGY_GET_FORMAT_WIZARD_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), G_SEGY_TYPE_FORMAT_WIZARD, GSEGYFormatWizardClass))

typedef gint (*GSEGYWizardCompareDataFunc) (gconstpointer a, gconstpointer  b, gpointer user_data, gboolean flag);

typedef struct _GSEGYFormatWizard GSEGYFormatWizard;
typedef struct _GSEGYFormatWizardClass GSEGYFormatWizardClass;

struct _GSEGYFormatWizard {
    GObject parent;
};

struct _GSEGYFormatWizardClass {
    GObjectClass parent_class;
};

GType g_segy_format_wizard_get_type (void);

GSEGYFormatWizard* g_segy_format_wizard_new (GSEGYEndianess *endianess);

const gchar* g_segy_format_wizard_get_name (GSEGYFormatWizard *self);
const gchar* g_segy_format_wizard_get_short_name (GSEGYFormatWizard *self);
const gchar* g_segy_format_wizard_get_files_name (GSEGYFormatWizard *self);
GPtrArray* g_segy_format_wizard_get_files_extensions (GSEGYFormatWizard *self);

guint16 g_segy_format_wizard_get_ebcdic_header_size (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_binary_header_size (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_trace_header_size (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_stanza_header_size (GSEGYFormatWizard *self);

guint16 g_segy_format_wizard_get_binary_header_number_of_fields (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_trace_header_number_of_fields (GSEGYFormatWizard *self);

gboolean g_segy_format_wizard_get_sample_interval_from_bin (GSEGYFormatWizard *self, guint8 *binary_header, guint16 *sample_interval);
gboolean g_segy_format_wizard_get_number_of_samples_from_bin (GSEGYFormatWizard *self, guint8 *binary_header, guint16 *number_of_samples);
gboolean g_segy_format_wizard_get_number_of_stanzas_from_bin (GSEGYFormatWizard *self, guint8 *binary_header, guint16 *number_of_stanzas);
gboolean g_segy_format_wizard_get_sample_format_id (GSEGYFormatWizard *self, guint8 *binary_header, guint8 *sample_id, guint8 *sample_size);
gboolean g_segy_format_wizard_get_default_sample_format_id (GSEGYFormatWizard *self, guint8 *sample_id, guint8 *sample_size);

gboolean g_segy_format_wizard_get_number_of_samples (GSEGYFormatWizard *self, guint8 *trace_header, guint16 *number_of_samples);
gboolean g_segy_format_wizard_get_first_sample_value (GSEGYFormatWizard *self, guint8 *trace_header, guint16 *first_sample_value);
gboolean g_segy_format_wizard_get_sample_interval (GSEGYFormatWizard *self, guint8 *trace_header, guint16 *sample_interval);

void g_segy_format_wizard_decode_ebcdic_header (GSEGYFormatWizard *self, guint8 *input_header, guint8 *output_header);
void g_segy_format_wizard_decode_binary_header (GSEGYFormatWizard *self, guint8 *input_header, guint8 *output_header);
void g_segy_format_wizard_decode_trace_header (GSEGYFormatWizard *self, guint8 *input_header, guint8 *output_header);
void g_segy_format_wizard_decode_sorting_fields (GSEGYFormatWizard *self, guint8 *input_fields, guint8 *output_fields);
void g_segy_format_wizard_decode_trace (GSEGYFormatWizard *self, guint8 sample_id, guint32 samples_num,
                                        guint8 *input_trace_buffer, gfloat *output_trace_buffer);

GPtrArray* g_segy_format_wizard_get_binary_header_fields_desc (GSEGYFormatWizard *self);
GPtrArray* g_segy_format_wizard_get_trace_header_fields_desc (GSEGYFormatWizard *self);
GPtrArray* g_segy_format_wizard_get_trace_header_fields_names (GSEGYFormatWizard *self);
GPtrArray* g_segy_format_wizard_get_sorting_fields_names (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_number_of_sorting_fields (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_sorting_desc_size (GSEGYFormatWizard *self);
guint16 g_segy_format_wizard_get_sorting_field_offset (GSEGYFormatWizard *self, guint16 field_number);

void g_segy_format_wizard_get_labels_for_binary_header (GSEGYFormatWizard *self, guint8 *binary_header,
                                                        GStringChunk **chunk, GPtrArray **labels);
void g_segy_format_wizard_get_labels_for_trace_header (GSEGYFormatWizard *self, guint8 *trace_header,
                                                       GStringChunk **chunk, GPtrArray **labels);

GSEGYWizardCompareDataFunc g_segy_format_wizard_get_compare_func_for_sorting_field (GSEGYFormatWizard *self,
                                                                                    gint16 field_number,
                                                                                    gboolean ascending);
void g_segy_format_wizard_get_label_for_sorting_field (GSEGYFormatWizard *self, guint16 field_number,
                                                       guint32 trace_index, GArray *sorting_content,
                                                       gchar *gbuffer, guint32 buffer_len);
void g_segy_format_wizard_get_labels_for_sorting_field (GSEGYFormatWizard *self, guint16 field_number,
                                                        GArray *traces_indices, GArray *sorting_content,
                                                        GStringChunk **chunk, GPtrArray **labels);
void g_segy_format_wizard_get_values_for_sorting_field (GSEGYFormatWizard *self, guint16 field_number,
                                                        GArray *traces_indices, GArray *sorting_content,
                                                        GArray **values);

G_END_DECLS
#endif /* __G_SEGY_FORMAT_WIZARD_H__ */
