/* 
 * GTKSEISVIEWGL - Library for rendering of 2D seismic data
 *
 * Copyright (C) 2006 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __GTK_LIGHT_DIRECTION_H__
#define __GTK_LIGHT_DIRECTION_H__

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define GTK_TYPE_LIGHT_DIRECTION            (gtk_light_direction_get_type ())
#define GTK_LIGHT_DIRECTION(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_LIGHT_DIRECTION, GtkLightDirection))
#define GTK_LIGHT_DIRECTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_LIGHT_DIRECTION, GtkLightDirectionClass))
#define GTK_IS_LIGHT_DIRECTION(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_LIGHT_DIRECTION))
#define GTK_IS_LIGHT_DIRECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_LIGHT_DIRECTION))
#define GTK_LIGHT_DIRECTION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_LIGHT_DIRECTION, GtkLightDirectionClass))

#define GTK_TYPE_LIGHT_POSITION             (gtk_light_position_get_type ())

typedef struct _GtkLightPosition GtkLightPosition;

struct _GtkLightPosition {
    gfloat x;
    gfloat y;
    gfloat z;
    gfloat w;
};

GtkLightPosition* gtk_light_position_copy (const GtkLightPosition *position);
void gtk_light_position_free (GtkLightPosition *position);
GType gtk_light_position_get_type (void) G_GNUC_CONST;

typedef struct _GtkLightDirection GtkLightDirection;
typedef struct _GtkLightDirectionClass GtkLightDirectionClass;

struct _GtkLightDirection {
    GtkDrawingArea parent;
};

struct _GtkLightDirectionClass {
    GtkDrawingAreaClass parent_class;
};

GType		gtk_light_direction_get_type (void) G_GNUC_CONST;
GtkWidget*	gtk_light_direction_new (void);

guint gtk_light_direction_get_max_lights (GtkLightDirection *self);
guint gtk_light_direction_get_num_lights (GtkLightDirection *self);
guint gtk_light_direction_get_active_light (GtkLightDirection *self);
void gtk_light_direction_get_diffuse_light_color (GtkLightDirection *self, GdkColor *color);
gfloat gtk_light_direction_get_diffuse_light_factor (GtkLightDirection *self);

void gtk_light_direction_set_num_lights (GtkLightDirection *self, guint num_lights);
void gtk_light_direction_set_active_light (GtkLightDirection *self, guint active_light);
void gtk_light_direction_set_diffuse_light_color (GtkLightDirection *self, const GdkColor *color);
void gtk_light_direction_set_diffuse_light_factor (GtkLightDirection *self, gfloat factor);

void gtk_light_direction_get_ambient_light_color (GtkLightDirection *self, GdkColor *color);
gfloat gtk_light_direction_get_ambient_light_factor (GtkLightDirection *self);

void gtk_light_direction_set_ambient_light_color (GtkLightDirection *self, const GdkColor *color);
void gtk_light_direction_set_ambient_light_factor (GtkLightDirection *self, gfloat factor);

void gtk_light_direction_get_diffuse_light_position (GtkLightDirection *self, GtkLightPosition *position);

void gtk_light_direction_reset_diffuse_light_position (GtkLightDirection *self);

void gtk_light_direction_redraw (GtkLightDirection *self);

G_END_DECLS

#endif /* __GTK_LIGHT_DIRECTION_H__ */
